<?php

namespace Drupal\gadget_chain_poc\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Site\Settings;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Controller for GadgetChainPocController routes.
 */
class GadgetChainPocController extends ControllerBase {

  /**
   * Checks access for a specific request.
   *
   * @param AccountInterface $account
   *   Run access checks for this account.
   *
   * @return AccessResultInterface
   *   The access result.
   */
  public function access(AccountInterface $account) {
    $override = Settings::getInstance()->get('gadget_chain_poc_free_access');
    return AccessResult::allowedIf($override || $account->hasPermission('administer site configuration'));
  }

  /**
   * Deserialize and be damned.
   *
   * @return Response
   *  JSON encoded or HTML-pretty printed deserialized payload.
   *
   * @throws NotFoundHttpException()
   */
  public function detonate() {
    $output = '';
    $request = \Drupal::requestStack()->getCurrentRequest();
    $payload = $request->get('payload');

    if (!empty($payload)) {
      if (!empty($request->get('base64'))) {
        $payload = base64_decode($payload);
      }

      if (!empty($request->get('tostring'))) {
        $output = (string) unserialize($payload);
      }
      else {
        $output = unserialize($payload);
      }
    }

    if (!empty($request->get('output')) && !empty($output)) {
      if ($request->getRequestFormat() === 'json') {
        return new JsonResponse($output);
      }
      else {
        $output_html = print_r($output, TRUE);
        $output_html = highlight_string($output_html, TRUE);
        return new Response($output_html);
      }
    }
    throw new NotFoundHttpException();
  }

}
